@@ -12,10 +12,16 @@ from typing import Generator, List, Optional, Tuple
 from astroid import context, inference_tip
 from astroid.builder import parse
 from astroid.const import PY37_PLUS, PY39_PLUS
-from astroid.exceptions import AstroidSyntaxError, InferenceError, MroError
+from astroid.exceptions import (
+    AstroidSyntaxError,
+    InferenceError,
+    MroError,
+    UseInferenceDefault,
+)
 from astroid.manager import AstroidManager
 from astroid.nodes.node_classes import (
     AnnAssign,
+    Assign,
     AssignName,
     Attribute,
     Call,
@@ -231,9 +237,11 @@ def infer_dataclass_attribute(
 
 
 def infer_dataclass_field_call(
-    node: AssignName, ctx: context.InferenceContext = None
+    node: Call, ctx: Optional[context.InferenceContext] = None
 ) -> Generator:
     """Inference tip for dataclass field calls."""
+    if not isinstance(node.parent, (AnnAssign, Assign)):
+        raise UseInferenceDefault
     field_call = node.parent.value
     default_type, default = _get_field_default(field_call)
     if not default_type:
