@@ -14,6 +14,7 @@
 # Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Ram Rachum <ram@rachum.com>
+# Copyright (c) 2021 Dimitri Prybysh <dmand@yandex.ru>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 David Liu <david@cs.toronto.edu>
 # Copyright (c) 2021 pre-commit-ci[bot] <bot@noreply.github.com>
@@ -484,13 +485,13 @@ def infer_typing_namedtuple_class(class_node, context=None):
     for method in class_node.mymethods():
         generated_class_node.locals[method.name] = [method]
 
-    for assign in class_node.body:
-        if not isinstance(assign, nodes.Assign):
-            continue
-
-        for target in assign.targets:
-            attr = target.name
-            generated_class_node.locals[attr] = class_node.locals[attr]
+    for body_node in class_node.body:
+        if isinstance(body_node, nodes.Assign):
+            for target in body_node.targets:
+                attr = target.name
+                generated_class_node.locals[attr] = class_node.locals[attr]
+        elif isinstance(body_node, nodes.ClassDef):
+            generated_class_node.locals[body_node.name] = [body_node]
 
     return iter((generated_class_node,))
 
